@@ -9,14 +9,14 @@ from physicalrisk.handler.constants.constants import RESOLUTION, FUTURE_MONTH
 from physicalrisk.handler.raster_handler.rasterhandler import RasterHandler
 from physicalrisk.handler.printMessageHandler.formatePrint import Formatter
 
-# import platform
-# import boto3
-# s3 = boto3.resource(
-#     service_name='s3',
-#     region_name='eu-west-2',
-#     aws_access_key_id='AKIAYHM23ZQQ4JOTA34C',
-#     aws_secret_access_key='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'
-# )
+import platform
+import boto3
+s3 = boto3.resource(
+    service_name='s3',
+    region_name='eu-west-2',
+    aws_access_key_id='AKIAYHM23ZQQ4JOTA34C',
+    aws_secret_access_key='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'
+)
 class Data_Handler():
 
     def __init__(self):
@@ -24,13 +24,11 @@ class Data_Handler():
             {'elevation': 9, 'precipitation': 9})
         self.df_to_predict = pd.DataFrame(columns=self.column_names)
         self.scenarios_based_future_precipitation = {
-            1: aws.CMIP6_ssp126_2021_2040,
-            2: aws.CMIP6_ssp126_2041_2060,
-            3: aws.CMIP6_ssp245_2021_2040,
-            4: aws.CMIP6_ssp245_2041_2060
+            1: 'WorldClim/FuturePrecipitation/wc2.1_2.5m_prec_CNRM-CM6-1_ssp126_2021-2040.tif',
+            2: 'WorldClim/FuturePrecipitation/wc2.1_2.5m_prec_CNRM-CM6-1_ssp126_2041-2060.tif'
         }
 
-    def build_prediction_data(self, input_long_lat: list[float], scenario):
+    def build_prediction_data(self, input_long_lat: list, scenario):
 
         future_precip_ml = self.load_future_precipitation(input_long_lat[0], input_long_lat[1], scenario)
         future_elevation_ml = self.add_in_elevation_feature(input_long_lat[0], input_long_lat[1])
@@ -83,7 +81,7 @@ class Data_Handler():
         # TODO: Questions: what does get raster feature do?
         #   what is AWSdata properties of elevation AWSdata (meter): tif file: array of value: pixel, get raster feature: convert lat, lon to certain pixel, take AWSdata from pixel, rearrange pixel
         #   put them into one by nine array.
-        elevation_data, _ = self.get_raster_feature(aws.elev_tif, longitude, latitude, RESOLUTION)
+        elevation_data, _ = self.get_raster_feature('WorldClim/Elevation/wc2.1_2.5m_elev.tif', longitude, latitude, RESOLUTION)
         elevation_ml = elevation_data.reshape(1, -1)
         # calculate the related 9 elevation point to the non-flood centroid
         # elevation_ml = elevation_ml - elevation_ml[0][4]
@@ -94,7 +92,7 @@ class Data_Handler():
         bounds = self.get_raster_bounds(latitude, longitude, resolution)
         # feature_filepath = path.join(settings.dataroot, feature_filename)  # location of AWSdata
         # feature_filename with /is a absolute file path, so previous componnet settings.dataroot is discarded
-        feature, lons, lats = RasterHandler.read_crop_geotif(path.join(aws.s3_bucket_path, feature_filename), bounds)
+        feature, lons, lats = RasterHandler.read_crop_geotif(path.join('/vsis3/bci-physical-risk-model/', feature_filename), bounds)
         metadata = {
             'lons': lons,
             'lats': lats
